EpubContextMenu class

The native text-selection context menu (mobile/desktop only).

Pass to EpubViewer.selectionContextMenu. Ignored on the web.

Constructors

EpubContextMenu({List<EpubContextMenuItem> items = const [], bool hideDefaultSystemItems = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hideDefaultSystemItems → bool
Whether to hide the platform's default selection menu items (Copy / Look Up / …), showing only items.
final
items → List<EpubContextMenuItem>
Custom menu items.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited