EpubController class

Constructors

EpubController()

Properties

hashCode int
The hash code for this object.
no setterinherited
requestTimeout Duration
Maximum time to wait for a request/response call before giving up.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webViewController ↔ EpubWebViewController?
Platform bridge to the epub.js runtime.
getter/setter pair

Methods

addHighlight({required String cfi, Color color = Colors.yellow, double opacity = 0.3}) → dynamic
Adds a highlight to epub viewer
addUnderline({required String cfi}) → dynamic
Adds a underline annotation
checkEpubLoaded() → dynamic
clearSelection() → dynamic
Clears any active text selection in the epub viewer
display({required String cfi}) → dynamic
Move epub view to specific area using Cfi string, XPath/XPointer, or chapter href
extractCurrentPageText() Future<EpubTextExtractRes>
Extracts text content from current page
extractText({required dynamic startCfi, required dynamic endCfi}) Future<EpubTextExtractRes>
Extract text from a given cfi range
getChapters() List<EpubChapter>
Returns list of EpubChapter from epub, should be called after onChaptersLoaded callback, otherwise returns empty list
getCurrentLocation() Future<EpubLocation>
Returns current location of epub viewer
getMetadata() Future<EpubMetadata>
getRectFromCfi(String cfiRange) Future<Rect?>
Get bounding rectangle for a given CFI range Returns viewer-relative coordinates in pixels, or null if it cannot be determined
moveToFistPage() → dynamic
Moves to the first page of the epub
moveToLastPage() → dynamic
Moves to the last page of the epub
next() → dynamic
Moves to next page in epub view
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseChapters() Future<List<EpubChapter>>
prev() → dynamic
Moves to previous page in epub view
removeHighlight({required String cfi}) → dynamic
Removes a highlight from epub viewer
removeUnderline({required String cfi}) → dynamic
Removes a underline from epub viewer
Search in epub using query string Returns a list of EpubSearchResult
setFlow({required EpubFlow flow}) → dynamic
Set EpubFlow value
setFontSize({required double fontSize}) → dynamic
Adjust font size in epub viewer
setManager({required EpubManager manager}) → dynamic
Set EpubManager value
setSpread({required EpubSpread spread}) → dynamic
Set EpubSpread value
setWebViewController(EpubWebViewController controller) → dynamic
toProgressPercentage(double progressPercent) → dynamic
Given a percentage moves to the corresponding page Progress percentage should be between 0.0 and 1.0
toString() String
A string representation of this object.
inherited
updateTheme({required EpubTheme theme}) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited