clearSelection method
dynamic
clearSelection()
Clears any active text selection in the epub viewer
Implementation
clearSelection() {
checkEpubLoaded();
webViewController?.callMethod('clearSelection');
}
Clears any active text selection in the epub viewer
clearSelection() {
checkEpubLoaded();
webViewController?.callMethod('clearSelection');
}