EpubLocation class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

EpubLocation({required String startCfi, required String endCfi, String? startXpath, String? endXpath, required double progress})
EpubLocation.fromJson(Map<String, dynamic> json)
factory

Properties

endCfi ↔ String
End cfi string of the page
getter/setter pair
endXpath ↔ String?
End xpath/XPointer string of the page
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
progress ↔ double
Progress percentage of location, value between 0.0 and 1.0
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCfi ↔ String
Start cfi string of the page
getter/setter pair
startXpath ↔ String?
Start xpath/XPointer string of the page
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited