EpubMetadata class

Constructors

EpubMetadata({String? title, String? author, String? language, String? identifier, String? publisher, String? description, String? date, String? subject, String? coverImage})
EpubMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

author → String?
final
coverImage → String?
final
date → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
final
language → String?
final
publisher → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
final
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited