EpubTextSelection class

Epub text selection callback object

Constructors

EpubTextSelection({required String selectedText, required String selectionCfi, String? selectionXpath})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedText → String
The selected text
final
selectionCfi → String
The cfi string of the selected text
final
selectionXpath → String?
The xpath/XPointer string of the selected text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited