onLocationLoaded property
Callback when the location are generated for epub, progress will be only available after this
Implementation
final VoidCallback? onLocationLoaded;
Callback when the location are generated for epub, progress will be only available after this
final VoidCallback? onLocationLoaded;