selectionContextMenu property
Context menu for text selection. If null, the default context menu will be used. Applies to mobile/desktop only; ignored on the web.
Implementation
final EpubContextMenu? selectionContextMenu;
Context menu for text selection. If null, the default context menu will be used. Applies to mobile/desktop only; ignored on the web.
final EpubContextMenu? selectionContextMenu;